@@ -6,14 +6,14 @@ test_that("styler can style package", {
   capture_output(expect_false({
     styled <- style_pkg(testthat_file("public-api", "xyzpackage"))
     any(styled$changed)
-    }))
+  }))
 })
 
 test_that("styler can style directory", {
   capture_output(expect_false({
     styled <- style_dir(testthat_file("public-api", "xyzdir"))
     any(styled$changed)
-    }))
+  }))
 })
 
 test_that("styler can style files", {
@@ -34,8 +34,9 @@ test_that("styler can style files", {
 
 test_that("styler does not return error when there is no file to style", {
   capture_output(expect_error(style_dir(
-    testthat_file("public-api", "xyzemptydir"), strict = FALSE), NA
-  ))
+    testthat_file("public-api", "xyzemptydir"),
+    strict = FALSE
+  ), NA))
 })
 
 context("public API - Rmd in style_file()")
@@ -43,7 +44,8 @@ context("public API - Rmd in style_file()")
 test_that("styler can style Rmd file", {
   capture_output(expect_false({
     out <- style_file(
-      testthat_file("public-api", "xyzfile_rmd", "random.Rmd"), strict = FALSE
+      testthat_file("public-api", "xyzfile_rmd", "random.Rmd"),
+      strict = FALSE
     )
     out$changed
   }))
@@ -67,32 +69,59 @@ test_that("styler handles malformed Rmd file and invalid R code in chunk", {
 context("messages are correct")
 
 test_that("messages (via cat()) of style_file are correct", {
-  skip_on_os("windows")
-  # Message if scope > line_breaks and code changes
-  temp_path <- copy_to_tempdir(testthat_file(
-    "public-api", "xyzdir-dirty", "dirty-sample-with-scope-tokens.R"
-  ))
-  expect_equal_to_reference(capture.output(
-    style_file(temp_path, scope = "tokens")),
-    testthat_file("public-api/xyzdir-dirty/dirty-reference-with-scope-tokens")
-  )
-  unlink(dirname(temp_path))
+  if (cli::is_utf8_output()) {
+    # if utf8 is available test under this and test  if it is not available
+    encodings <- list(TRUE)
+  } else {
+    # if utf8 is not available, only test under that
+    encodings <- list()
+  }
+  for (encoding in c(encodings, FALSE)) {
+    withr::with_options(
+      list(cli.unicode = encoding), {
+        # Message if scope > line_breaks and code changes
+        temp_path <- copy_to_tempdir(testthat_file(
+          "public-api", "xyzdir-dirty", "dirty-sample-with-scope-tokens.R"
+        ))
+        expect_equal_to_reference(
+          capture.output(
+            style_file(temp_path, scope = "tokens")
+          ),
+          testthat_file(paste0(
+            "public-api/xyzdir-dirty/dirty-reference-with-scope-tokens-",
+            ifelse(cli::is_utf8_output(), "utf8", "non-utf8")
+          ))
+        )
+        unlink(dirname(temp_path))
 
-  # No message if scope > line_breaks and code does not change
-  temp_path <- copy_to_tempdir(testthat_file("public-api", "xyzdir-dirty", "clean-sample-with-scope-tokens.R"))
-  expect_equal_to_reference(
-    capture.output(style_file(temp_path, scope = "tokens")),
-    testthat_file("public-api/xyzdir-dirty/clean-reference-with-scope-tokens")
-  )
-  unlink(dirname(temp_path))
+        # No message if scope > line_breaks and code does not change
+        temp_path <- copy_to_tempdir(testthat_file(
+          "public-api", "xyzdir-dirty", "clean-sample-with-scope-tokens.R"
+        ))
+        expect_equal_to_reference(
+          capture.output(style_file(temp_path, scope = "tokens")),
+          testthat_file(paste0(
+            "public-api/xyzdir-dirty/clean-reference-with-scope-tokens-",
+            ifelse(cli::is_utf8_output(), "utf8", "non-utf8")
+          ))
+        )
+        unlink(dirname(temp_path))
 
-  # No message if scope <= line_breaks even if code is changed.
-  temp_path <- copy_to_tempdir(testthat_file("public-api", "xyzdir-dirty", "dirty-sample-with-scope-spaces.R"))
-  expect_equal_to_reference(
-    capture.output(style_file(temp_path, scope = "spaces")),
-    testthat_file("public-api/xyzdir-dirty/dirty-reference-with-scope-spaces")
-  )
-  unlink(dirname(temp_path))
+        # No message if scope <= line_breaks even if code is changed.
+        temp_path <- copy_to_tempdir(testthat_file(
+          "public-api", "xyzdir-dirty", "dirty-sample-with-scope-spaces.R"
+        ))
+        expect_equal_to_reference(
+          capture.output(style_file(temp_path, scope = "spaces")),
+          testthat_file(paste0(
+            "public-api/xyzdir-dirty/dirty-reference-with-scope-spaces-",
+            ifelse(cli::is_utf8_output(), "utf8", "non-utf8")
+          ))
+        )
+        unlink(dirname(temp_path))
+      }
+    )
+  }
 })
 
 context("public API - Rmd in style_dir()")
@@ -100,7 +129,8 @@ context("public API - Rmd in style_dir()")
 test_that("styler can style R and Rmd files via style_dir()", {
   msg <- capture_output(
     style_dir(testthat_file("public-api", "xyz-r-and-rmd-dir"),
-              filetype = c("R", "Rmd"))
+      filetype = c("R", "Rmd")
+    )
   )
   expect_true(any(grepl("random-script-in-sub-dir.R", msg, fixed = TRUE)))
   expect_true(any(grepl("random-rmd-script.Rmd", msg, fixed = TRUE)))
@@ -109,7 +139,8 @@ test_that("styler can style R and Rmd files via style_dir()", {
 test_that("styler can style Rmd files only via style_dir()", {
   msg <- capture_output(
     style_dir(testthat_file("public-api", "xyz-r-and-rmd-dir"),
-              filetype = "Rmd")
+      filetype = "Rmd"
+    )
   )
   expect_true(any(grepl("random-rmd-script.Rmd", msg, fixed = TRUE)))
   expect_false(any(grepl("random-script-in-sub-dir.R", msg, fixed = TRUE)))
@@ -118,7 +149,8 @@ test_that("styler can style Rmd files only via style_dir()", {
 test_that("styler can style .r and .rmd files via style_dir()", {
   msg <- capture_output(
     style_dir(testthat_file("public-api", "xyz-r-and-rmd-dir"),
-              filetype = c(".r", ".rmd"))
+      filetype = c(".r", ".rmd")
+    )
   )
   expect_true(any(grepl("random-script-in-sub-dir.R", msg, fixed = TRUE)))
   expect_true(any(grepl("random-rmd-script.Rmd", msg, fixed = TRUE)))
@@ -129,20 +161,21 @@ context("public API - Rmd in style_pkg()")
 test_that("styler can style R and Rmd files via style_pkg()", {
   msg <- capture_output(
     style_pkg(testthat_file("public-api", "xyzpackage-rmd"),
-              filetype = c("R", "Rmd"))
+      filetype = c("R", "Rmd")
+    )
   )
   expect_true(any(grepl("hello-world.R", msg, fixed = TRUE)))
   expect_true(any(grepl("test-package-xyz.R", msg, fixed = TRUE)))
   expect_true(any(grepl("random.Rmd", msg, fixed = TRUE)))
   expect_true(any(grepl("README.Rmd", msg, fixed = TRUE)))
   expect_false(any(grepl("RcppExports.R", msg, fixed = TRUE)))
-
 })
 
 test_that("styler can style Rmd files only via style_pkg()", {
   msg <- capture_output(
     style_pkg(testthat_file("public-api", "xyzpackage-rmd"),
-              filetype = "Rmd")
+      filetype = "Rmd"
+    )
   )
   expect_false(any(grepl("hello-world.R", msg, fixed = TRUE)))
   expect_false(any(grepl("test-package-xyz.R", msg, fixed = TRUE)))
@@ -160,7 +193,8 @@ context("public API - Rnw in style_file()")
 test_that("styler can style Rnw file", {
   capture_output(expect_false({
     out <- style_file(
-      testthat_file("public-api", "xyzfile-rnw", "random.Rnw"), strict = FALSE
+      testthat_file("public-api", "xyzfile-rnw", "random.Rnw"),
+      strict = FALSE
     )
     out$changed
   }))
@@ -186,7 +220,8 @@ context("public API - Rnw in style_pkg()")
 test_that("styler can style R, Rmd and Rnw files via style_pkg()", {
   msg <- capture_output(
     style_pkg(testthat_file("public-api", "xyzpackage-rnw"),
-              filetype = c("R", "Rmd", "Rnw"))
+      filetype = c("R", "Rmd", "Rnw")
+    )
   )
   expect_true(any(grepl("hello-world.R", msg, fixed = TRUE)))
   expect_true(any(grepl("test-package-xyz.R", msg, fixed = TRUE)))
@@ -198,7 +233,8 @@ test_that("styler can style R, Rmd and Rnw files via style_pkg()", {
 test_that("styler can style Rnw files only via style_pkg()", {
   msg <- capture_output(
     style_pkg(testthat_file("public-api", "xyzpackage-rnw"),
-              filetype = "Rnw")
+      filetype = "Rnw"
+    )
   )
   expect_false(any(grepl("hello-world.R", msg, fixed = TRUE)))
   expect_false(any(grepl("test-package-xyz.R", msg, fixed = TRUE)))
